# 📰 Metron-Tagger News

## v2.2.4

### 🐛 Bug Fixes

- Fix Tagging Bug with Existing `ComicInfo.xml` @bpepple (#114)
- Fix bug in duplicate image detection when attempting to hash a bad image.
  (#105)

### 🧰 Maintenance

- Update Pillow and Other Deps @bpepple (#115)
- Bump actions/cache from 2 to 4 @dependabot (#111)
- Bump actions/checkout from 2 to 4 @dependabot (#107)
- Bump release-drafter/release-drafter from 5 to 6 @dependabot (#110)
- Bump github/codeql-action from 1 to 3 @dependabot (#109)
- Bump JRubics/poetry-publish from 1.17 to 2.0 @dependabot (#108)
- Bump actions/setup-python from 2 to 5 @dependabot (#106)

## v2.2.3

### Changes

### 🧰 Maintenance

- Update minimum required version of `comicfn2dict`.
- Rework project files to use a Makefile for development.

## v2.2.2

### Changes

### 🐛 Bug Fixes

- Strip commas and `&` from series name @bpepple (#103)
